@@ -180,7 +180,7 @@ class Container():
       etc_passwd.write(apps_user.passwd_entry())
       etc_passwd.write("\n")
       etc_shadow.write(apps_user.shadow_entry())
-      etc_passwd.write("\n")
+      etc_shadow.write("\n")
       open(self.vz_root_path + "/etc/sudoers", 'a', 0440).write("%apps           ALL=NOPASSWD:/bin/su - apps\n")
       apps_groups = apps_user.groups()
     else:
@@ -190,9 +190,9 @@ class Container():
     err.write(account.passwd_entry())
     err.write("\n")
     etc_passwd.write(account.passwd_entry())
-    err.write("\n")
+    etc_passwd.write("\n")
     etc_shadow.write(account.shadow_entry())
-    err.write("\n")
+    etc_shadow.write("\n")
 
     # Add CMS groups to the /etc/group file in the container/VEID...
     # normally CMS gids are above 500 
