@@ -74,7 +74,10 @@ class BasicHost:
     #process = subprocess.Popen("""whoami""", stdout= subprocess.PIPE)
     #me = process.communicate()[0]
     #if me == MW_USER + "\n" or me == MW_USER:
-    if login == MW_USER:
+    if login == 'root':
+      # make available to everyone
+      knownhosts = '/etc/ssh/ssh_known_hosts'
+    elif login == MW_USER:
       knownhosts = '/var/www/.ssh/known_hosts'
     else:
       knownhosts = '/root/.ssh/known_hosts'
