@@ -518,18 +518,36 @@ class Session:
       # FRONT_LISTEN_HOST = ''
       proxy_vars = {}
       if os.path.isfile(FRONT_PROXY_CONFIG_FILE):
-	# read values into proxy_vars, otherwise "global name 'FRONT_...' is not defined"
-	# because they go into locals but can't access them
+        # read values into proxy_vars, otherwise "global name 'FRONT_...' is not defined"
+        # because they go into locals but can't access them
         execfile(FRONT_PROXY_CONFIG_FILE, proxy_vars)
       else:
-	log("front proxy config file is not readable")
-      # log("front listen host is '%s'" % str(proxy_vars['FRONT_LISTEN_HOST']))
-      if proxy_vars['FRONT_LISTEN_SSL']:
+        log("front proxy config file is not readable")
+      try:
+        if proxy_vars['FRONT_LISTEN_SSL']:
+          prefix = "https://"
+        else:
+          prefix = "http://"
+      except KeyError:
         prefix = "https://"
-      else:
-	prefix = "http://"
-      if proxy_vars['FRONT_LISTEN_HOST'] == '':
-	# guess it from hostname of hub_url and prepend https://proxy.
+      try:
+        if proxy_vars['FRONT_LISTEN_HOST'] == '':
+          # guess it from hostname of hub_url and prepend https://proxy.
+          host = hub_url
+          idx = host.find('://')
+          if idx != -1:
+            host = host[idx+3:]
+          idx = host.find('/')
+          if idx != -1:
+            host = host[0:idx]
+          prefix = prefix + "proxy." + host
+        else:
+          # log("front listen host is '%s'" % str(proxy_vars['FRONT_LISTEN_HOST']))
+          prefix = prefix + proxy_vars['FRONT_LISTEN_HOST']
+      except KeyError:
+        # duplicated code...
+        log("FRONT_LISTEN_HOST not found, guessing from hub_url")
+        # guess it from hostname of hub_url and prepend https://proxy.
         host = hub_url
         idx = host.find('://')
         if idx != -1:
@@ -538,12 +556,13 @@ class Session:
         if idx != -1:
           host = host[0:idx]
         prefix = prefix + "proxy." + host
-      else:
-	prefix = prefix + proxy_vars['FRONT_LISTEN_HOST']
-      if proxy_vars['FRONT_LISTEN_PORT'] == 443:
-        redirect_url = prefix
-      else:
-        redirect_url = prefix + ":" + proxy_vars['FRONT_LISTEN_PORT']
+      try:
+        if proxy_vars['FRONT_LISTEN_PORT'] == 443:
+          redirect_url = prefix
+        else:
+          redirect_url = prefix + ":%d" % proxy_vars['FRONT_LISTEN_PORT']
+      except KeyError:
+          redirect_url = prefix
       log("redirect_url is '%s'" % str(redirect_url ))
       row = db.getrow(
         """SELECT fileperm.cookie,display.dispnum,fileperm.fileuser
